NeighborAwarenessNetworkingServiceMatch

Struct NeighborAwarenessNetworkingServiceMatch 

pub struct NeighborAwarenessNetworkingServiceMatch<'a>(/* private fields */);
Available on crate feature unstable only.
See WifiEvent.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl NeighborAwarenessNetworkingServiceMatch<'_>

pub fn subscribe_id(&self) -> u8

Get the Subscribe Service ID.

pub fn publish_id(&self) -> u8

Get the Publish Service ID.

pub fn pub_if_mac(&self) -> &[u8]

Get the NAN Interface MAC of the Publisher.

pub fn update_pub_id(&self) -> bool

Indicates whether publisher’s service ID needs to be updated.