NeighborAwarenessNetworkingStarted

Struct NeighborAwarenessNetworkingStarted 

pub struct NeighborAwarenessNetworkingStarted;
Available on crate feature unstable only.
See WifiEvent.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.